@@ -22,18 +22,21 @@ class BinarySensor(Device):
 
     # pylint: disable=too-many-instance-attributes
 
-    CONTEXT_TIMEOUT = 1
+    DEFAULT_CONTEXT_TIMEOUT = 1
 
-    def __init__(self,
-                 xknx,
-                 name,
-                 group_address_state=None,
-                 sync_state=True,
-                 ignore_internal_state=False,
-                 device_class=None,
-                 reset_after=None,
-                 actions=None,
-                 device_updated_cb=None):
+    def __init__(
+        self,
+        xknx,
+        name,
+        group_address_state=None,
+        sync_state=True,
+        ignore_internal_state=False,
+        device_class=None,
+        reset_after=None,
+        actions=None,
+        context_timeout=DEFAULT_CONTEXT_TIMEOUT,
+        device_updated_cb=None,
+    ):
         """Initialize BinarySensor class."""
         # pylint: disable=too-many-arguments
         super().__init__(xknx, name, device_updated_cb)
@@ -44,20 +47,23 @@ class BinarySensor(Device):
         self.device_class = device_class
         self.ignore_internal_state = ignore_internal_state
         self.reset_after = reset_after
-        self.state = False
+        self.state = None
 
+        self._context_timeout = context_timeout
         self._count_set_on = 0
         self._count_set_off = 0
         self._last_set = None
         self._reset_task = None
+        self._context_task = None
         # TODO: log a warning if reset_after and sync_state are true ? This could cause actions to self-fire.
-        self.remote_value = RemoteValueSwitch(xknx,
-                                              group_address_state=group_address_state,
-                                              sync_state=sync_state,
-                                              device_name=self.name,
-                                              # after_update called internally
-                                              after_update_cb=self._state_from_remote_value
-                                              )
+        self.remote_value = RemoteValueSwitch(
+            xknx,
+            group_address_state=group_address_state,
+            sync_state=sync_state,
+            device_name=self.name,
+            # after_update called internally
+            after_update_cb=self._state_from_remote_value,
+        )
 
     def _iter_remote_values(self):
         """Iterate the devices RemoteValue classes."""
@@ -68,48 +74,74 @@ class BinarySensor(Device):
         if self._reset_task:
             self._reset_task.cancel()
 
+        if self._context_task:
+            self._context_task.cancel()
+
     @classmethod
     def from_config(cls, xknx, name, config):
         """Initialize object from configuration structure."""
-        group_address_state = \
-            config.get('group_address_state')
-        sync_state = \
-            config.get('sync_state', True)
-        device_class = \
-            config.get('device_class')
-        ignore_internal_state = \
-            config.get('ignore_internal_state', False)
+        group_address_state = config.get("group_address_state")
+        context_timeout = config.get("context_timeout", 1)
+        sync_state = config.get("sync_state", True)
+        device_class = config.get("device_class")
+        ignore_internal_state = config.get("ignore_internal_state", False)
         actions = []
         if "actions" in config:
             for action in config["actions"]:
                 action = Action.from_config(xknx, action)
                 actions.append(action)
 
-        return cls(xknx,
-                   name,
-                   group_address_state=group_address_state,
-                   sync_state=sync_state,
-                   ignore_internal_state=ignore_internal_state,
-                   device_class=device_class,
-                   actions=actions)
+        return cls(
+            xknx,
+            name,
+            group_address_state=group_address_state,
+            sync_state=sync_state,
+            ignore_internal_state=ignore_internal_state,
+            context_timeout=context_timeout,
+            device_class=device_class,
+            actions=actions,
+        )
 
     async def _state_from_remote_value(self):
-        """Update the internal state from ReomteValue (Callback)."""
+        """Update the internal state from RemoteValue (Callback)."""
         await self._set_internal_state(self.remote_value.value)
 
     async def _set_internal_state(self, state):
         """Set the internal state of the device. If state was changed after_update hooks and connected Actions are executed."""
         if state != self.state or self.ignore_internal_state:
             self.state = state
-            counter = self.bump_and_get_counter(state)
-            await self.after_update()
+            self.bump_and_get_counter(state)
 
-            for action in self.actions:
-                if action.test_if_applicable(self.state, counter):
-                    await action.execute()
+            if self.ignore_internal_state:
+                if self._context_task:
+                    self._context_task.cancel()
+                self._context_task = self.xknx.loop.create_task(
+                    self._counter_task(self._context_timeout)
+                )
+            else:
+                await self._trigger_callbacks()
+
+    async def _counter_task(self, wait_seconds: float):
+        """Trigger after 1 second to prevent double triggers."""
+        await asyncio.sleep(wait_seconds)
+        await self._trigger_callbacks()
+
+    async def _trigger_callbacks(self):
+        """Trigger callbacks for device and execute actions if any."""
+        await self.after_update()
+
+        for action in self.actions:
+            if action.test_if_applicable(self.state, self.counter):
+                await action.execute()
+
+    @property
+    def counter(self):
+        """Return current counter for sensor."""
+        return self._count_set_on if self.state else self._count_set_off
 
     def bump_and_get_counter(self, state):
         """Bump counter and return the number of times a state was set to the same value within CONTEXT_TIMEOUT."""
+
         def within_same_context():
             """Check if state change was within same context (e.g. 'Button was pressed twice')."""
             if self._last_set is None:
@@ -118,7 +150,7 @@ class BinarySensor(Device):
             new_set_time = time.time()
             time_diff = new_set_time - self._last_set
             self._last_set = new_set_time
-            return time_diff < self.CONTEXT_TIMEOUT
+            return time_diff < self._context_timeout
 
         if within_same_context():
             if state:
@@ -139,12 +171,12 @@ class BinarySensor(Device):
         """Process incoming GROUP WRITE telegram."""
         if await self.remote_value.process(telegram, always_callback=True):
 
-            if self.reset_after is not None and \
-                    self.state:
+            if self.reset_after is not None and self.state:
                 if self._reset_task:
                     self._reset_task.cancel()
                 self._reset_task = self.xknx.loop.create_task(
-                    self._reset_state(self.reset_after/1000))
+                    self._reset_state(self.reset_after / 1000)
+                )
 
     async def _reset_state(self, wait_seconds):
         await asyncio.sleep(wait_seconds)
@@ -152,7 +184,7 @@ class BinarySensor(Device):
 
     def is_on(self):
         """Return if binary sensor is 'on'."""
-        return self.state
+        return bool(self.state)
 
     def is_off(self):
         """Return if binary sensor is 'off'."""
@@ -160,5 +192,6 @@ class BinarySensor(Device):
 
     def __str__(self):
         """Return object as readable string."""
-        return '<BinarySensor name="{0}" remote_value="{1}" state="{2}"/>' \
-            .format(self.name, self.remote_value.group_addr_str(), self.state)
+        return '<BinarySensor name="{}" remote_value="{}" state="{}"/>'.format(
+            self.name, self.remote_value.group_addr_str(), self.state
+        )
