@@ -14,13 +14,15 @@ from .device import Device
 class Sensor(Device):
     """Class for managing a sensor."""
 
-    def __init__(self,
-                 xknx,
-                 name,
-                 group_address_state=None,
-                 sync_state=True,
-                 value_type=None,
-                 device_updated_cb=None):
+    def __init__(
+        self,
+        xknx,
+        name,
+        group_address_state=None,
+        sync_state=True,
+        value_type=None,
+        device_updated_cb=None,
+    ):
         """Initialize Sensor class."""
         # pylint: disable=too-many-arguments
         super().__init__(xknx, name, device_updated_cb)
@@ -31,7 +33,8 @@ class Sensor(Device):
             sync_state=sync_state,
             value_type=value_type,
             device_name=self.name,
-            after_update_cb=self.after_update)
+            after_update_cb=self.after_update,
+        )
 
     def _iter_remote_values(self):
         """Iterate the devices RemoteValue classes."""
@@ -40,15 +43,17 @@ class Sensor(Device):
     @classmethod
     def from_config(cls, xknx, name, config):
         """Initialize object from configuration structure."""
-        group_address_state = config.get('group_address_state')
-        sync_state = config.get('sync_state', True)
-        value_type = config.get('value_type')
+        group_address_state = config.get("group_address_state")
+        sync_state = config.get("sync_state", True)
+        value_type = config.get("value_type")
 
-        return cls(xknx,
-                   name,
-                   group_address_state=group_address_state,
-                   sync_state=sync_state,
-                   value_type=value_type)
+        return cls(
+            xknx,
+            name,
+            group_address_state=group_address_state,
+            sync_state=sync_state,
+            value_type=value_type,
+        )
 
     async def process_group_write(self, telegram):
         """Process incoming GROUP WRITE telegram."""
@@ -68,9 +73,9 @@ class Sensor(Device):
 
     def __str__(self):
         """Return object as readable string."""
-        return '<Sensor name="{0}" ' \
-               'sensor="{1}" value="{2}" unit="{3}"/>' \
-            .format(self.name,
-                    self.sensor_value.group_addr_str(),
-                    self.resolve_state(),
-                    self.unit_of_measurement())
+        return '<Sensor name="{}" ' 'sensor="{}" value="{}" unit="{}"/>'.format(
+            self.name,
+            self.sensor_value.group_addr_str(),
+            self.resolve_state(),
+            self.unit_of_measurement(),
+        )
